import { HttpClient } from "@angular/common/http";
import { Injectable } from "@angular/core";
import { throwError } from "rxjs";
import { catchError } from "rxjs/operators";
import { AppSettings } from "src/app/model/config/app-settings";

@Injectable({
  providedIn: "root",
})
export class SettingsService {
  appSettings!: AppSettings;

  constructor(private http: HttpClient) {}

  loadSettings(): Promise<AppSettings> {
    return new Promise((resolve, reject) => {
      this.http
        .get<AppSettings>("/assets/config.json")
        .pipe(
          catchError((error) => {
            reject(error);
            return throwError(() => error);
          }),
        )
        .subscribe((settings) => {
          this.appSettings = settings;
        });
    });
  }

  public getTermsURL(): string {
    if (!this.appSettings || !this.appSettings.TermsUrl) {
      return "/404";
    }
    return this.appSettings.TermsUrl;
  }

  public getPrivacyURL(): string {
    if (!this.appSettings || !this.appSettings.PrivacyURL) {
      return "/404";
    }
    return this.appSettings.PrivacyURL;
  }

  public getImprintURL(): string {
    if (!this.appSettings || !this.appSettings.ImprintURL) {
      return "/404";
    }
    return this.appSettings.ImprintURL;
  }
}
